@@ -1491,16 +1491,13 @@ cached: list[str] = [
     "aws-lex-resourcepolicy.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
-    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
-    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
-    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
@@ -1707,6 +1704,7 @@ cached: list[str] = [
     "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
+    "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
@@ -1783,9 +1781,12 @@ cached: list[str] = [
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
     "aws-voiceid-domain.json",
+    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
+    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
