@@ -110,6 +110,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -411,6 +412,8 @@ types: list[str] = [
     "AWS::EC2::LocalGatewayRouteTable",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
     "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation",
+    "AWS::EC2::LocalGatewayVirtualInterface",
+    "AWS::EC2::LocalGatewayVirtualInterfaceGroup",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
@@ -768,6 +771,7 @@ types: list[str] = [
     "AWS::Lightsail::Container",
     "AWS::Lightsail::Database",
     "AWS::Lightsail::Disk",
+    "AWS::Lightsail::DiskSnapshot",
     "AWS::Lightsail::Instance",
     "AWS::Lightsail::InstanceSnapshot",
     "AWS::Lightsail::LoadBalancer",
@@ -886,6 +890,7 @@ types: list[str] = [
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::ObservabilityAdmin::OrganizationCentralizationRule",
     "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
     "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::Omics::RunGroup",
@@ -1348,6 +1353,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1503,6 +1509,7 @@ cached: list[str] = [
     "aws-codedeploy-deploymentgroup.json",
     "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
+    "aws-codepipeline-webhook.json",
     "aws-codestar-githubrepository.json",
     "aws-codestarconnections-connection.json",
     "aws-codestarconnections-repositorylink.json",
@@ -1680,6 +1687,8 @@ cached: list[str] = [
     "aws-ec2-localgatewayroutetable.json",
     "aws-ec2-localgatewayroutetablevirtualinterfacegroupassociation.json",
     "aws-ec2-localgatewayroutetablevpcassociation.json",
+    "aws-ec2-localgatewayvirtualinterface.json",
+    "aws-ec2-localgatewayvirtualinterfacegroup.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
@@ -1800,6 +1809,7 @@ cached: list[str] = [
     "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-entityresolution-idmappingworkflow.json",
     "aws-entityresolution-idnamespace.json",
     "aws-entityresolution-matchingworkflow.json",
     "aws-entityresolution-policystatement.json",
@@ -2033,6 +2043,7 @@ cached: list[str] = [
     "aws-lightsail-container.json",
     "aws-lightsail-database.json",
     "aws-lightsail-disk.json",
+    "aws-lightsail-disksnapshot.json",
     "aws-lightsail-instance.json",
     "aws-lightsail-instancesnapshot.json",
     "aws-lightsail-loadbalancer.json",
@@ -2040,17 +2051,14 @@ cached: list[str] = [
     "aws-lightsail-staticip.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
-    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
-    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
-    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-lookoutequipment-inferencescheduler.json",
     "aws-lookoutvision-project.json",
@@ -2125,6 +2133,7 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
@@ -2142,6 +2151,7 @@ cached: list[str] = [
     "aws-networkmanager-transitgatewayregistration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-observabilityadmin-organizationcentralizationrule.json",
     "aws-observabilityadmin-organizationtelemetryrule.json",
     "aws-observabilityadmin-telemetryrule.json",
     "aws-omics-rungroup.json",
@@ -2273,9 +2283,12 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -2360,8 +2373,8 @@ cached: list[str] = [
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolio.json",
+    "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
-    "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
@@ -2456,9 +2469,12 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
+    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
