@@ -681,6 +681,7 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -1002,15 +1003,12 @@ cached: list[str] = [
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
     "aws-logs-delivery.json",
-    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
-    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
-    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
