@@ -4,12 +4,16 @@ __all__ = [
     "GetAtt",
     "GetAttType",
     "PROVIDER_SCHEMA_MANAGER",
+    "OTHER_SCHEMA_MANAGER",
     "Schema",
     "SchemaPatch",
+    "patch",
+    "reset",
 ]
 
 from cfnlint.schema._exceptions import ResourceNotFoundError
 from cfnlint.schema._getatts import AttributeDict
+from cfnlint.schema._patch import SchemaPatch, patch, reset
 from cfnlint.schema._schema import Schema
 from cfnlint.schema.manager import PROVIDER_SCHEMA_MANAGER
-from cfnlint.schema.patch import SchemaPatch
+from cfnlint.schema.other_schema_manager import OTHER_SCHEMA_MANAGER
